import { Component, OnInit, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as echarts from 'echarts';
import { AiApiService } from '../../../../lib/ai-api.service';

@Component({
  selector: 'app-page-interview',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './page-interview.html',
  styleUrl: './page-interview.scss'
})
export class PageInterview implements OnInit, AfterViewInit {
  // 计时相关
  remainingTime = '10:00'; 
  progress = 0;
  
  // 面试状态控制
  interviewEnded = false;
  isAnalyzing = false;
  showSubmitButton = false;
  showCancelButton = false;
  isFollowUpQuestion = false;
  showQuestionCard = true;
  showRadarChart = false;
  
  // 语音相关
  isListening = false;
  isSpeaking = false;
  userAnswer = '';
  recognition: any;
  interimTranscript = '';
  // 问题列表
  mainQuestions = [
    "欢迎参加本次AI面试，我是您的面试官AI助手。",
    "首先，请简单介绍一下您自己。",
    "您在过去工作中遇到的最大技术挑战是什么？您是如何解决的？",
    "请描述一个您与团队意见不合时，您是如何处理的案例。"
  ];
  
  currentQuestionIndex = 0;
  currentQuestion = this.mainQuestions[0];
  
  // 对话记录
  messages: {sender: 'ai' | 'user', text: string}[] = [];
  
  // 头像状态
  avatarImage = "assets/default-avatar.svg";
  expressionText = "等待开始...";
  
  // 评估指标
  metrics = {
    expressiveness: 0,
    professionalism: 0,
    relevance: 0
  };

  @ViewChild('dialogContainer') dialogContainer!: ElementRef;
  private radarChart: any;

  constructor(private aiService: AiApiService) {
    // 初始化语音识别
    this.initSpeechRecognition();
  }

  ngOnInit(): void {
    this.initConversation();
    this.initProgressTimer();
  }

  ngAfterViewInit(): void {
    this.initRadarChart();
  }



  private initSpeechRecognition() {
    const SpeechRecognition = (window as any).SpeechRecognition || (window as any).webkitSpeechRecognition;
    if (SpeechRecognition) {
      this.recognition = new SpeechRecognition();
      this.recognition.lang = 'zh-CN';
      this.recognition.interimResults = true; // 启用临时结果
      this.recognition.continuous = true;

      this.recognition.onresult = (event: any) => {
        let finalTranscript = '';
        let interimTranscript = '';

        for (let i = event.resultIndex; i < event.results.length; i++) {
          const transcript = event.results[i][0].transcript;
          if (event.results[i].isFinal) {
            finalTranscript += transcript;
          } else {
            interimTranscript += transcript;
          }
        }

        if (finalTranscript) {
          this.userAnswer = finalTranscript;
          this.showSubmitButton = true;
          this.showCancelButton = true;
        }
        this.interimTranscript = interimTranscript;
      };

      this.recognition.onerror = (event: any) => {
        console.error('语音识别错误:', event.error);
        this.updateAvatarState('listening');
      };

      this.recognition.onend = () => {
        if (this.isListening) {
          this.stopVoiceInput();
        }
      };
    }
  }

  private initProgressTimer(): void {
    const totalSeconds = 10 * 60; // 10分钟 = 600秒
    let elapsedSeconds = 0;
    
    const timer = setInterval(() => {
      if (this.interviewEnded) {
        clearInterval(timer);
        return;
      }
      
      elapsedSeconds++;
      this.progress = Math.min((elapsedSeconds / totalSeconds) * 100, 100);
      
      // 更新时间显示
      const remainingSeconds = totalSeconds - elapsedSeconds;
      const minutes = Math.floor(remainingSeconds / 60);
      const seconds = remainingSeconds % 60;
      this.remainingTime = `${minutes}:${seconds < 10 ? '0' + seconds : seconds}`;
      
      // 时间到自动结束
      if (elapsedSeconds >= totalSeconds) {
        clearInterval(timer);
        this.addAIMessage("时间到，本次面试结束");
        this.interviewEnded = true;
      }
    }, 1000); // 改为每秒更新一次
  }

  initConversation(): void {
    this.addAIMessage(this.mainQuestions[0]);
    setTimeout(() => {
      this.askQuestion(1);
    }, 1500);
  }

  askQuestion(index: number): void {
    if (index >= this.mainQuestions.length || this.interviewEnded) {
      this.endInterview();
      return;
    }
    
    this.currentQuestionIndex = index;
    this.isFollowUpQuestion = false;
    this.currentQuestion = this.mainQuestions[index];
    
    this.addAIMessage(this.currentQuestion);
    this.updateAvatarState('speaking');
    this.speakText(this.currentQuestion); // 自动语音播放问题
  }

  async askFollowUpQuestion(followUpText: string): Promise<void> {
    if (this.interviewEnded) return;
    
    this.isFollowUpQuestion = true;
    this.currentQuestion = followUpText;
    
    this.addAIMessage("关于您刚才的回答，我有一个跟进问题...");
    setTimeout(() => {
      this.addAIMessage(this.currentQuestion);
      this.updateAvatarState('speaking');
    }, 1000);
  }

  endInterview(): void {
    this.interviewEnded = true;
    this.addAIMessage("感谢您参与本次面试，祝您有美好的一天！");
    this.updateAvatarState('default');
  }

  restartInterview(): void {
    this.interviewEnded = false;
    this.currentQuestionIndex = 0;
    this.currentQuestion = this.mainQuestions[0];
    this.messages = [];
    this.metrics = { expressiveness: 0, professionalism: 0, relevance: 0 };
    this.progress = 0;
    this.initConversation();
  }

  addAIMessage(text: string): void {
    this.messages.push({
      sender: 'ai',
      text: text
    });
    this.scrollToBottom();
  }

  addUserMessage(text: string): void {
    this.messages.push({
      sender: 'user',
      text: text
    });
    this.scrollToBottom();
  }

  private scrollToBottom(): void {
    setTimeout(() => {
      this.dialogContainer.nativeElement.scrollTop = this.dialogContainer.nativeElement.scrollHeight;
    }, 0);
  }

  speakText(text: string): void {
    if (this.isSpeaking || !text) return;
    
    this.isSpeaking = true;
    this.updateAvatarState('speaking');

    const utterance = new SpeechSynthesisUtterance(text);
    utterance.lang = 'zh-CN';
    utterance.rate = 0.9;
    utterance.pitch = 1;

    utterance.onend = () => {
      this.isSpeaking = false;
      if (!this.interviewEnded) {
        this.updateAvatarState('listening');
      }
    };

    speechSynthesis.speak(utterance);
  }

  startVoiceInput(): void {
    if (!this.recognition || this.isSpeaking || this.isAnalyzing) return;
    
    this.isListening = true;
    this.userAnswer = '';
    this.updateAvatarState('listening');
    this.recognition.start();
  }

  stopVoiceInput(): void {
    this.isListening = false;
    if (this.recognition) {
      this.recognition.stop();
    }
    this.updateAvatarState('waiting');
  }

  async submitAnswer(): Promise<void> {
    if (!this.userAnswer || this.isAnalyzing) return;
    
    this.showSubmitButton = false;
    this.showCancelButton = false;
    this.addUserMessage(this.userAnswer);
    
    this.isAnalyzing = true;
    this.updateAvatarState('analyzing');

    try {
      const evaluation = await this.aiService.evaluateInterviewAnswer(
        this.currentQuestion,
        this.userAnswer
      );

      // 更新评估指标
      this.metrics = {
        expressiveness: evaluation.metrics.expressiveness,
        professionalism: evaluation.metrics.professionalism,
        relevance: evaluation.metrics.relevance
      };

      // 添加AI反馈
      this.addAIMessage(evaluation.feedback);

      // 检查回答相关性
      if (evaluation.metrics.relevance < 30) {
        this.addAIMessage("您的回答与问题相关性较低，本次面试结束。");
        this.interviewEnded = true;
        return;
      }

      // 处理问题流程
      if (!this.isFollowUpQuestion && this.currentQuestionIndex !== 1) {
        // 主问题（非自我介绍）需要追问
        setTimeout(() => {
          this.askFollowUpQuestion(evaluation.followUpQuestion);
        }, 1500);
      } else {
        // 进入下一个问题
        setTimeout(() => {
          this.askQuestion(this.currentQuestionIndex + 1);
        }, 1500);
      }
    } catch (error) {
      console.error('评估失败:', error);
      this.addAIMessage("分析完成，让我们继续下一个问题");
      this.askQuestion(this.currentQuestionIndex + 1);
    } finally {
      this.isAnalyzing = false;
      this.userAnswer = '';
    }
  }

  cancelAnswer(): void {
    this.showSubmitButton = false;
    this.showCancelButton = false;
    this.userAnswer = '';
    this.updateAvatarState('listening');
  }

  playQuestion(): void {
    if (!this.isListening && !this.isSpeaking) {
      this.speakText(this.currentQuestion);
    }
  }

  updateAvatarState(state: 'speaking' | 'listening' | 'waiting' | 'analyzing' | 'default'): void {
    switch(state) {
      case 'speaking':
        this.avatarImage = "assets/ai-speaking.svg";
        this.expressionText = "正在提问...";
        break;
      case 'listening':
        this.avatarImage = "assets/ai-listening.svg";
        this.expressionText = "正在聆听...";
        break;
      case 'waiting':
        this.avatarImage = "assets/ai-waiting.svg";
        this.expressionText = "等待确认...";
        break;
      case 'analyzing':
        this.avatarImage = "assets/ai-analyzing.svg";
        this.expressionText = "分析回答中...";
        break;
      default:
        this.avatarImage = "assets/default-avatar.svg";
        this.expressionText = "AI面试官";
    }
  }

  toggleRadarChart(): void {
    this.showRadarChart = !this.showRadarChart;
    if (this.showRadarChart) {
      setTimeout(() => {
        this.initRadarChart();
      }, 0);
    }
  }

  private initRadarChart(): void {
    if (!this.showRadarChart || this.interviewEnded) return;
    
    const chartDom = document.getElementById('radarChart');
    if (!chartDom) return;
    
    if (this.radarChart) {
      this.radarChart.dispose();
    }
    
    this.radarChart = echarts.init(chartDom);
    
    const option = {
      backgroundColor: 'transparent',
      tooltip: {},
      radar: {
        shape: 'circle',
        indicator: [
          { name: '表达能力', max: 100 },
          { name: '专业深度', max: 100 },
          { name: '岗位匹配', max: 100 },
          { name: '应变能力', max: 100 },
          { name: '沟通技巧', max: 100 },
          { name: '知识广度', max: 100 }
        ],
        radius: '65%',
        axisName: { color: '#4A5568' },
        splitArea: { areaStyle: { color: ['rgba(42, 92, 170, 0.1)'] } },
        axisLine: { lineStyle: { color: 'rgba(42, 92, 170, 0.3)' } },
        splitLine: { lineStyle: { color: 'rgba(42, 92, 170, 0.3)' } }
      },
      series: [{
        type: 'radar',
        data: [
          {
            value: [
              this.metrics.expressiveness,
              this.metrics.professionalism,
              this.metrics.relevance,
              (this.metrics.expressiveness + this.metrics.professionalism) / 2,
              this.metrics.expressiveness,
              this.metrics.professionalism
            ],
            name: '当前表现',
            areaStyle: { color: 'rgba(42, 92, 170, 0.4)' },
            lineStyle: { width: 2, color: 'rgba(42, 92, 170, 0.8)' },
            itemStyle: { color: '#2A5CAA' }
          },
          {
            value: [70, 80, 85, 75, 65, 70],
            name: '岗位要求',
            areaStyle: { color: 'rgba(255, 107, 53, 0.2)' },
            lineStyle: { width: 2, color: 'rgba(255, 107, 53, 0.8)' },
            itemStyle: { color: '#FF6B35' }
          }
        ]
      }]
    };
    
    this.radarChart.setOption(option);
    
    window.addEventListener('resize', () => {
      this.radarChart?.resize();
    });
  }

  
}